==> IO-K8s-1.000.tar.gz: IO-K8s-1.000/lib/IO/K8s/Api/Core/V1/VsphereVirtualDiskVolumeSource.pm <==
package IO::K8s::Api::Core::V1::VsphereVirtualDiskVolumeSource;
# ABSTRACT: Represents a vSphere volume resource.
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s fsType => Str;


k8s storagePolicyID => Str;


k8s storagePolicyName => Str;


k8s volumePath => Str, 'required';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Core::V1::VsphereVirtualDiskVolumeSource - Represents a vSphere volume resource.

=head1 VERSION

version 1.000

=head2 fsType

fsType is filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

=head2 storagePolicyID

storagePolicyID is the storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName.

=head2 storagePolicyName

storagePolicyName is the storage Policy Based Management (SPBM) profile name.

=head2 volumePath

volumePath is the path that identifies vSphere volume vmdk

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

==> IO-K8s-1.001.tar.gz: IO-K8s-1.001/lib/IO/K8s/Api/Core/V1/VsphereVirtualDiskVolumeSource.pm <==
package IO::K8s::Api::Core::V1::VsphereVirtualDiskVolumeSource;
# ABSTRACT: Represents a vSphere volume resource.
our $VERSION = '1.001';
use IO::K8s::Resource;

k8s fsType => Str;


k8s storagePolicyID => Str;


k8s storagePolicyName => Str;


k8s volumePath => Str, 'required';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Core::V1::VsphereVirtualDiskVolumeSource - Represents a vSphere volume resource.

=head1 VERSION

version 1.001

=head2 fsType

fsType is filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

=head2 storagePolicyID

storagePolicyID is the storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName.

=head2 storagePolicyName

storagePolicyName is the storage Policy Based Management (SPBM) profile name.

=head2 volumePath

volumePath is the path that identifies vSphere volume vmdk

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
